Flexget Web Interface Under Development

We need your help! If you are an AngularJS developer or can help with the layout/design/css then please join in the effort!

The interface is not yet ready for end users. Consider this preview only state.

If you still use it anyways, please do report back to us how well it works, issues, ideas etc..

There is a functional API with documentation available at /api

More information: https://flexget.com/Web-UI

Gitter Chat: https://gitter.im/Flexget/Flexget

GitHub Wiki Chat Forum